<?php
/*
 * Project: NodeMap2.0
 * File: ErrorHandler.class.php
 * Purpose: Handling (PHP) errors generated by the application
 */

/*
 * PHP errors:
 *   E_ERROR ( integer )				Fatal run-time errors. These indicate errors that can not be recovered from, such as a memory allocation problem. Execution of the script is halted.
 *   E_WARNING ( integer )				Run-time warnings (non-fatal errors). Execution of the script is not halted.
 *   E_PARSE ( integer )				Compile-time parse errors. Parse errors should only be generated by the parser.
 *   E_NOTICE ( integer )				Run-time notices. Indicate that the script encountered something that could indicate an error, but could also happen in the normal course of running a script.
 *   E_CORE_ERROR ( integer )			Fatal errors that occur during PHP's initial startup. This is like an E_ERROR, except it is generated by the core of PHP.	since PHP 4
 *   E_CORE_WARNING ( integer )			Warnings (non-fatal errors) that occur during PHP's initial startup. This is like an E_WARNING, except it is generated by the core of PHP.	since PHP 4
 *   E_COMPILE_ERROR ( integer )		Fatal compile-time errors. This is like an E_ERROR, except it is generated by the Zend Scripting Engine.	since PHP 4
 *   E_COMPILE_WARNING ( integer )		Compile-time warnings (non-fatal errors). This is like an E_WARNING, except it is generated by the Zend Scripting Engine.	since PHP 4
 *   E_USER_ERROR ( integer )			User-generated error message. This is like an E_ERROR, except it is generated in PHP code by using the PHP function trigger_error().	since PHP 4
 *   E_USER_WARNING ( integer )			User-generated warning message. This is like an E_WARNING, except it is generated in PHP code by using the PHP function trigger_error().	since PHP 4
 *   E_USER_NOTICE ( integer )			User-generated notice message. This is like an E_NOTICE, except it is generated in PHP code by using the PHP function trigger_error().	since PHP 4
 *   E_STRICT ( integer )				Enable to have PHP suggest changes to your code which will ensure the best interoperability and forward compatibility of your code.	since PHP 5
 *   E_RECOVERABLE_ERROR ( integer )	Catchable fatal error. It indicates that a probably dangerous error occured, but did not leave the Engine in an unstable state. If the error is not caught by a user defined handle (see also set_error_handler()), the application aborts as it was an E_ERROR.	since PHP 5.2.0
 *   E_ALL ( integer )					All errors and warnings, as supported, except of level E_STRICT in PHP < 6.
 */

/*
 * Function: NodeErrorHandler
 * Parameters: int $errno, string $errstr, string $errfile, int $errline, array $errcontext
 * Function: Handling with errors, decides what log level it is and send it to LogHandler
 */
function NodeErrorHandler(int $errno, string $errstr, string $errfile, int $errline, array $errcontext) {
	switch ($errno) {
		case E_ERROR:
			trigger_log(SYSLOG_ERR, $errstr, $errfile, $errline);
			break;
		case E_WARNING:
			trigger_log(SYSLOG_WARNING, $errstr, $errfile, $errline);
			break;
		case E_PARSE:
			trigger_log(SYSLOG_ERR, $errstr, $errfile, $errline);
			break;
		case E_NOTICE:
			trigger_log(SYSLOG_NOTICE, $errstr, $errfile, $errline);
			break;
		case E_CORE_ERROR:
			trigger_log(SYSLOG_ERR, $errstr, $errfile, $errline);
			break;
		case E_CORE_WARNING:
			trigger_log(SYSLOG_WARNING, $errstr, $errfile, $errline);
			break;
		case E_COMPILE_ERROR:
			trigger_log(SYSLOG_ERR, $errstr, $errfile, $errline);
			break;
		case E_COMPILE_WARNING:
			trigger_log(SYSLOG_WARNING, $errstr, $errfile, $errline);
			break;
		case E_USER_ERROR:
			trigger_log(SYSLOG_ERR, $errstr, $errfile, $errline);
			break;
		case E_USER_WARNING:
			trigger_log(SYSLOG_WARNING, $errstr, $errfile, $errline);
			break;
		case E_USER_NOTICE:
			trigger_log(SYSLOG_NOTICE, $errstr, $errfile, $errline);
			break;
		case E_STRICT:
			trigger_log(SYSLOG_NOTICE, $errstr, $errfile, $errline);
			break;
		case E_RECOVERABLE_ERROR:
			trigger_log(SYSLOG_ERR, $errstr, $errfile, $errline);
			break;
		default:
			trigger_log(SYSLOG_NOTICE, $errstr, $errfile, $errline);
			break;
	}

	/* Don't execute PHP internal error handler */
	return true;
}

set_exception_handler('NodeErrorHandler');